import { mapGetters } from "vuex";

import { queryOrg as fwkQueryOrg } from "string-public-design-3/api/framework/account/org";


import {
  queryTerm, //获取学期 
  queryOrgs,//获取二级学院
  querySchoolRegion,//获取校区
} from "string-edu-middleware/api/public/task";

// 查询字典项
import { queryDictionariesItems } from "string-edu-middleware/api/dictionaries/dictionariesItems";


import {
  getBaseDepartmentList,//获取教学单位数据 
} from "string-edu-middleware/utils/education-cache/base";


//  导出接口
import {
  exportChangeExport,//顶岗实习的统计接口
  exportSelectionAll,//导出所有选课页面所有统计接口
} from "string-edu-middleware/api/static_export/index.js";

export default {
  computed: {
    ...mapGetters("user", ["userInfo"]),
    ...mapGetters("base", [
      // "baseDepartmentList",//教学单位
      "baseTermList",//学期  
      "baseCurrentTermId",//当前学期 ID
    ])
  },

  methods: {

    // 获取教学单位-暂代的数据
    getBaseDepartment () {
      let department = getBaseDepartmentList();
      return department;
    },

    // 根据用户的部门id去获取教学单位的id 
    getBaseDepartmentId () {
      let department = getBaseDepartmentList();
      department = department.filter(item => this.userInfo.mainOrgId == item.admOrg);
      if (department.length > 0)  //如果获取到对应的教学单位id
        return department[0].id;
      return null;
    },

    // 根据用户的部门取二级学院id
    getBaseCollegeId () {
      let collegeId = getBaseDepartmentList();
      collegeId = collegeId.filter(item => this.userInfo.mainOrgId == item.admOrg);
      if (collegeId.length > 0)  //如果获取到对应的二级学院id
        return collegeId[0].chkOrg;
      return null;
    },


    // 查询学期
    fetchBaseTerm (status = true, iscurrent = null, isMobile = false) {
      // isMobile 判断是否是移动端
      return new Promise((resolve, reject) => {
        queryTerm({
          status: status,
          iscurrent: iscurrent
        }).then(({ data, result, message }) => {
          let currentId = null;
          let currentInfo = {};

          if (result == 1) {
            // 获取当前学期
            data.forEach((element) => {
              // 处理移动端显示的问题 需要加value 和 text
              element.text = element.code;
              element.value = element.id;

              if (element.isCurrent === 1) {
                currentId = element.id;
                currentInfo = element;
              }
            });
            resolve({
              data,
              currentId,//当前学期Id
              currentInfo: currentInfo,//当前学期的所有数据
            });
          } else {
            this.$message({
              message: message,
              type: "error"
            })
            reject({ code: -1, message: "查询学期出错" });
          }
        }).catch(e => {
          this.$message({
            message: "查询学期出错",
            type: "error"
          });
          reject({ code: -1, message: "查询学期出错" });
        })
      });
    },

    // 查询教务二级学院
    fetchBaseOrgs () {
      return new Promise((resolve, reject) => {
        queryOrgs({
          category: "3",
          type: "JW",
        }).then(({ data, result, message }) => {
          if (result == 1) {
            // 处理移动端显示的问题 需要加value 和 text
            data.forEach((element) => {
              element.text = element.name;
              element.value = element.id;
            });
            resolve({ data })
          } else {
            this.$message({
              message: message,
              type: "error"
            })
            reject({ code: -1, message: "查询二级学院出错" });
          }
        }).catch(e => {
          this.$message({
            message: "查询二级学院出错",
            type: "error"
          });
          reject({ code: -1, message: "查询二级学院出错" });
        })
      })
    },

    // 查询教务二级学院--属于新版的查询二级学院的接口
    fetchBaseOrgsFWK () {
      return new Promise((resolve, reject) => {
        fwkQueryOrg({
          depth: "3",
          type: "JW",
        }).then((res) => {
          let data = [];
          if (res.state == 200) {
            res.data.records.forEach(element => {
              element.text = element.orgName;
              element.value = element.orgId;
              element.orgname = element.orgName;
              element.orgid = element.orgId;
              data.push(element);
            })
            resolve({ data: data });
          } else {
            this.$message.error(`获取学院失败：${res.message}`);
          }
        }).catch(e => {
          this.$message({
            message: "查询二级学院出错",
            type: "error"
          });
          reject({ code: -1, message: "查询二级学院出错" });
        })
      })
    },




    // 获取行政部门
    fetchBaseXZOrg () {
      return new Promise((resolve, reject) => {
        // 教务教学单位
        queryOrgs({
          category: 3,
          type: "XZ"
        }).then(({ data, result, message }) => {
          if (result == 1) {
            resolve({
              data
            });
          } else {
            this.$message({
              message: message,
              type: "error"
            })
            reject({ code: -1, message: message });
          }
        }).catch(e => {
          this.$message({
            message: "查询部门错误",
            type: "error"
          })
          reject({ code: -1, message: "查询部门错误" });
        })
      });
    },


    // 获取校区
    fetchBaseSchoolRegion () {
      return new Promise((resolve, reject) => {
        // 校区
        querySchoolRegion({
          status: true
        }).then(({ data, result, message }) => {
          if (result == 1) {
            data.forEach((element) => {
              // 处理移动端显示的问题 需要加value 和 text
              element.text = element.name;
              element.value = element.id;
            });

            resolve({ data });
          } else {
            this.$message({
              message: message,
              type: "error"
            })
            reject({ code: -1, message: message });
          }
        }).catch(e => {
          this.$message({
            message: "查询部门错误",
            type: "error"
          })
          reject({ code: -1, message: "查询部门错误" });
        })
      });
    },

    // -----注：以后这里的所有函数都在开头加一个com-----
    // 清空数据
    xmcClearInfomation (_this, ...keys) {
      // 这里的清空相当于重置到初始值，如果一开始就赋值，则不建议用这个清空数据

      for (let i = 0; i < keys.length; i++) {
        Object.assign(_this.$data[keys[i]], _this.$options.data()[keys[i]])
      }
    },


    // 只能输入正数，并且保留两位小数
    xmcLsnQtyValidate (params) {
      //先把非数字的都替换掉，除了数字和.
      params = params.replace(/[^\d.]/g, "");
      //保证只有出现一个.而没有多个.
      params = params.replace(/\.{2,}/g, ".");

      //必须保证第一个为数字而不是.
      params = params.replace(/^\./g, "");

      //保证.只出现一次，而不能出现两次以上
      params = params
        .replace(".", "$#$")
        .replace(/\./g, "")
        .replace("$#$", ".");
      //只能输入2位小数
      params = params.replace(/^(\-)*(\d+)\.(\d\d).*$/, "$1$2.$3");
      return params;

      // 使用方法，一个是键盘按下进行判断，一个是失去焦点进行判断,在el-input使用
      // @keyup.native="form.sumWorkLoadNum=lsnQtyValidate(form.sumWorkLoadNum)"
      // @blur="form.sumWorkLoadNum=lsnQtyValidate(form.sumWorkLoadNum)"

    },

    // 清空数据的函数  this.formData[item].constructor ==String 
    xmcClearFormData (params, stopKey = [], defaultData = null) {
      //  1. params:{}-默认的对象数据，只接收对象
      //  2.stopKey:[]-指定某些key不用清理，用数组存储
      //  3.defaultData:{}-有一些key值不能清空成默认的样子，可以随时更改

      /**
        * 
        * defaultData={
        * isBoolean:false,
        * isString:"",
        * isArray:[],
        * isObject:{},
        * isNumber:null
        * } 
        */

      // 循环清空数据
      for (var item in params) {

        let stop = false;
        stopKey.forEach(key => {
          if (key == item) {
            stop = true;
          }
        });
        // 判断当前key值是否需要清理，如果不需要则跳过,判断数据是否不为null，undefined
        if (stop || (!params[item] || params[item] == null || params[item] == undefined || params[item] == NaN)) {
          continue;
        }
        if (params[item].constructor == String) {
          params[item] = null;
        } else if (params[item].constructor == Object) {
          params[item] = {};
        } else if (params[item].constructor == Array) {
          params[item] = [];
        } else if (params[item].constructor == Number) {
          params[item] = 0;
        }

        // 判断布尔值
        else if (params[item].constructor == Boolean) {
          if (defaultData && defaultData.isBoolean) {
            params[item] = defaultData.isBoolean;
          } else {
            params[item] = false;
          }
        }
      }
    },

    // 查询字典项的接口 
    xmcQueryDictionaries (mainId) {
      // isMobile 判断是否是移动端
      return new Promise((resolve, reject) => {
        queryDictionariesItems({ mainId }).then(({ data, result, message }) => {
          if (result == 1) {
            resolve({
              data,
            });
          } else {
            this.$message({
              message: message,
              type: "error"
            })
            reject({ code: -1, message: "查询字典项出错" });
          }
        }).catch(e => {
          this.$message({
            message: "查询字典项出错",
            type: "error"
          });
          reject({ code: -1, message: "查询字典项出错" });
        })
      });
    },


    // 给不同学校配置的不同属性和配置
    configSchools () {
      /**
       * gzcl  贵州财经学院
       */
      if (window.stringEducation.schoolName == 'gzcl') {
        return false;
      }
    },




    // 导出不同统计页面不同维度的数据（用excel导出）
    onStaticExport (condition, exportName, tabActive, tabPane) {
      /**
       * condition  当前统计查询条件
       * exportName 当前统计页面名称
       * tabActive  当前统计维度id
       **/

      /**记录exportName 有多少个
       *  course_selections - 从选课页面过来
       */

      let params = "";  //导出查询条件
      let url = ""; //下载的路径 
      let tabName = "";
      tabPane.forEach(value => {
        if (value.key == tabActive) {
          tabName = value.title;
        }
      })

      for (let item in condition) {
        // 判断：key值是pageIndex，pageSize,或key值为null或者空字符串，都不计算 
        if (item == 'pageIndex' || item == 'pageSize' || condition[item] == null || condition[item] == '') {
          continue;
        }
        params += `${item}=${condition[item]}&`;
      }

      this.$confirm(`您正在导出【${tabName}】维度统计数据,导出数据的范围来源于顶部搜索框，是否继续导出？`, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        console.log("-----------");
        console.log(exportName);
        switch (exportName) {
          case 'practice': //顶岗实习
            url = exportChangeExport(params, tabActive, exportName);
            console.log("读取返回值");
            break;
          default:
            url = exportSelectionAll(params, tabActive, exportName);
        }

        window.location.href = url;
      }).catch(() => {
      });
    },




  },
}


