import JsCookies from 'js-cookie'

const cookies = {
    /**
   * @description 存储 cookie 值
   * @param {String} name cookie name
   * @param {String} value cookie value
   * @param {Object} setting cookie setting
   * @param {Boolean} Whether the prefix
   *
   */
    set: function (name = 'default', value = '', cookieSetting = {}, isPrefix = true) {
        // 配置
        const currentCookieSetting = {
            expires: null, // 过期时间
        }
        Object.assign(currentCookieSetting, cookieSetting)
        // 赋值
        JsCookies.set(isPrefix ? `ansoft-${name}` : name, value, currentCookieSetting)
    },
    /**
   * @description 获取 cookie 值
   * @param {String} name cookie name
   * @param {Boolean} Whether the prefix
   */
    get: function (name = 'default', isPrefix = true) {
        return JsCookies.get(isPrefix ? `ansoft-${name}` : name)
    },
    /**
   * @description 获取 cookie 全部的值
   */
    getAll: function () {
        return JsCookies.get()
    },
    /**
   * @description 删除 cookie
   * @param {String} name cookie name
   * @param {Boolean} Whether the prefix
   */
    remove: function (name = 'default', isPrefix = true) {
        return JsCookies.remove(isPrefix ? `ansoft-${name}` : name)
    }
}

export default cookies
